Crate audyo

Crate audyo 

Structs

SampleBuffer
Buffer containing samples
i24
A signed 24-bit integer sample with an internal signed 32-bit integer representation.
u24
An unsigned 24-bit integer sample with an internal unsigned 32-bit integer representation.

Enums

Channels
Enum representing a channel layout
DecodeError
Enum representing decoding errors

Functions

decode
Decodes an audio file in source Returns a tuple of the source bitrate and a buffer with decoded samples
encode_vorbis
Function for encoding a buffer using ogg vorbis given an average bitrate